pycocoa.screens

Package pycocoa :: Module screens |
[frames] | no frames]

# Module screens

Types Frame and Screen, wrapping ObjC `NSScreen`.

Version: 21.11.04

Classes
| Frame A screen frame, wrapping ObjC NSRect_t.
| Screen Screen Python Type, wrapping ObjC NSRect_t.
| BuiltInScreen The BuiltIn screen.
| DeepestScreen The Deepest screen, the one with most colors.
| ExternalScreen An External screen or monitor.
| MainScreen A Main screen, the one with the menu bar, key focus, etc.

Variables
| __all__ = `_ALL_LAZY.screens`
| Screens = `(BuiltInScreen(NSScreen, name='BuiltIn'), ExternalSc`...``

Variables Details

  ### Screens Value:
      (BuiltInScreen(NSScreen, name='BuiltIn'), ExternalScreen(NSScreen, nam
      e='External'))